"""This module contains the general information for EquipmentPciDef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentPciDefConsts:
    DEVICE_TYPE_BROADCOM57712_NIC = "Broadcom57712Nic"
    DEVICE_TYPE_BROADCOM_NIC = "BroadcomNic"
    DEVICE_TYPE_EMULEX_FC = "EmulexFC"
    DEVICE_TYPE_EMULEX_NIC = "EmulexNic"
    DEVICE_TYPE_FUSION_HBA = "FusionHba"
    DEVICE_TYPE_GPU_AMD = "GpuAmd"
    DEVICE_TYPE_GPU_NVIDIA = "GpuNvidia"
    DEVICE_TYPE_INTEL_ICH10_RHBA = "IntelICH10RHba"
    DEVICE_TYPE_INTEL_NIC = "IntelNic"
    DEVICE_TYPE_LSIMEGA_RAID3008 = "LSIMegaRaid3008"
    DEVICE_TYPE_LAGUNA_BEACH = "LagunaBeach"
    DEVICE_TYPE_LAGUNA_BEACH_PLUS = "LagunaBeachPlus"
    DEVICE_TYPE_LAGUNA_ROCK = "LagunaRock"
    DEVICE_TYPE_LAGUNA_ROCK_PLUS = "LagunaRockPlus"
    DEVICE_TYPE_LEWISBURG_PSATA = "LewisburgPSata"
    DEVICE_TYPE_LEWISBURG_PSATA_AHCI = "LewisburgPSataAhci"
    DEVICE_TYPE_LEWISBURG_SSATA_SW_RAID = "LewisburgSSataSwRaid"
    DEVICE_TYPE_LODI_HBA = "LodiHba"
    DEVICE_TYPE_LSI1064_EHBA = "Lsi1064EHba"
    DEVICE_TYPE_LSI1068_EHBA = "Lsi1068EHba"
    DEVICE_TYPE_LSI_EXTERNAL_MEGA_RAID_HBA = "LsiExternalMegaRaidHba"
    DEVICE_TYPE_LSI_MEGA_RAID_HBA = "LsiMegaRaidHba"
    DEVICE_TYPE_LSI_WALNUT_CREEK_HBA = "LsiWalnutCreekHba"
    DEVICE_TYPE_M2_HW_RAID_MARVELL_HBA = "M2HwRaidMarvellHba"
    DEVICE_TYPE_MAX_COUNT = "MaxCount"
    DEVICE_TYPE_MELLANOX_NIC = "MellanoxNic"
    DEVICE_TYPE_MENLO_EMULEX_HBA = "MenloEmulexHba"
    DEVICE_TYPE_MENLO_QLOGIC_FC_HBA = "MenloQlogicFcHba"
    DEVICE_TYPE_MEZZ_DUBLIN_QLOGIC_FC_HBA = "MezzDublinQlogicFcHba"
    DEVICE_TYPE_MEZZ_SCHULZ_QLOGIC_FC_HBA = "MezzSchulzQlogicFcHba"
    DEVICE_TYPE_MEZZ_TIGER_SHARK_HBA = "MezzTigerSharkHba"
    DEVICE_TYPE_NVME_HBA = "NvmeHba"
    DEVICE_TYPE_NVME_INTEL_HBA = "NvmeIntelHba"
    DEVICE_TYPE_NVME_MEZZ = "NvmeMezz"
    DEVICE_TYPE_NVME_WD_HBA = "NvmeWdHba"
    DEVICE_TYPE_PCI_DUBLIN_QLOGIC_FC_HBA = "PciDublinQlogicFcHba"
    DEVICE_TYPE_PCI_EVEREST_NIC = "PciEverestNic"
    DEVICE_TYPE_PCI_INTEL_X520_NIC = "PciIntelX520Nic"
    DEVICE_TYPE_PCI_INTEL_X550_NIC = "PciIntelX550Nic"
    DEVICE_TYPE_PCI_INTEL_X710_NIC = "PciIntelX710Nic"
    DEVICE_TYPE_PCI_MPCISCO_NIC = "PciMPCiscoNic"
    DEVICE_TYPE_PCI_NIANTIC_NIC = "PciNianticNic"
    DEVICE_TYPE_PCI_PLX_SWITCH = "PciPlxSwitch"
    DEVICE_TYPE_PCI_QLOGIC8362_FC_HBA = "PciQlogic8362FcHba"
    DEVICE_TYPE_PCI_QLOGIC_BIG_BEAR = "PciQlogicBigBear"
    DEVICE_TYPE_PCI_SCHULZ_QLOGIC_FC_HBA = "PciSchulzQlogicFcHba"
    DEVICE_TYPE_PCI_TIGER_SHARK_HBA = "PciTigerSharkHba"
    DEVICE_TYPE_PISMO_BEACH = "PismoBeach"
    DEVICE_TYPE_PISMO_ROCK = "PismoRock"
    DEVICE_TYPE_QLOGIC_FC = "QlogicFC"
    DEVICE_TYPE_QLOGIC_NIC = "QlogicNic"
    DEVICE_TYPE_SATA_HBA = "SataHba"
    DEVICE_TYPE_TALLADEGA = "Talladega"
    DEVICE_TYPE_UNKNOWN = "Unknown"
    DEVICE_TYPE_WELLSBURG_HBA = "WellsburgHba"
    DEVICE_TYPE_ZUMA_BEACH = "ZumaBeach"
    DEVICE_TYPE_ZUMA_ROCK = "ZumaRock"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"


class EquipmentPciDef(ManagedObject):
    """This is EquipmentPciDef class."""

    consts = EquipmentPciDefConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("EquipmentPciDef", "equipmentPciDef", "pci-[name]", VersionMeta.Version141i, "InputOutput", 0xff, [], [""], ['adaptorFruCapProvider', 'adaptorUnit', 'equipmentCoprocessorUnitCapProvider', 'equipmentGraphicsCardCapProvider', 'equipmentLocalDiskControllerCapProvider', 'equipmentPciSwitchCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "device": MoPropertyMeta("device", "device", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "device_type": MoPropertyMeta("device_type", "deviceType", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["Broadcom57712Nic", "BroadcomNic", "EmulexFC", "EmulexNic", "FusionHba", "GpuAmd", "GpuNvidia", "IntelICH10RHba", "IntelNic", "LSIMegaRaid3008", "LagunaBeach", "LagunaBeachPlus", "LagunaRock", "LagunaRockPlus", "LewisburgPSata", "LewisburgPSataAhci", "LewisburgSSataSwRaid", "LodiHba", "Lsi1064EHba", "Lsi1068EHba", "LsiExternalMegaRaidHba", "LsiMegaRaidHba", "LsiWalnutCreekHba", "M2HwRaidMarvellHba", "MaxCount", "MellanoxNic", "MenloEmulexHba", "MenloQlogicFcHba", "MezzDublinQlogicFcHba", "MezzSchulzQlogicFcHba", "MezzTigerSharkHba", "NvmeHba", "NvmeIntelHba", "NvmeMezz", "NvmeWdHba", "PciDublinQlogicFcHba", "PciEverestNic", "PciIntelX520Nic", "PciIntelX550Nic", "PciIntelX710Nic", "PciMPCiscoNic", "PciNianticNic", "PciPlxSwitch", "PciQlogic8362FcHba", "PciQlogicBigBear", "PciSchulzQlogicFcHba", "PciTigerSharkHba", "PismoBeach", "PismoRock", "QlogicFC", "QlogicNic", "SataHba", "Talladega", "Unknown", "WellsburgHba", "ZumaBeach", "ZumaRock"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x10, 1, 512, None, [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["local", "pending-policy", "policy"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "subdevice": MoPropertyMeta("subdevice", "subdevice", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "subvendor": MoPropertyMeta("subvendor", "subvendor", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "device": "device", 
        "deviceType": "device_type", 
        "dn": "dn", 
        "intId": "int_id", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "subdevice": "subdevice", 
        "subvendor": "subvendor", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.device = None
        self.device_type = None
        self.int_id = None
        self.policy_level = None
        self.policy_owner = None
        self.sacl = None
        self.status = None
        self.subdevice = None
        self.subvendor = None
        self.vendor = None

        ManagedObject.__init__(self, "EquipmentPciDef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for MoKvCfgHolder ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MoKvCfgHolderConsts:
    FILE_TX_ADMIN_STATE_DISABLED = "disabled"
    FILE_TX_ADMIN_STATE_ENABLED = "enabled"
    OPER_STATE_CONFIG_FAILURE = "config-failure"
    OPER_STATE_NOT_SUPPORTED = "not-supported"
    OPER_STATE_OK = "ok"


class MoKvCfgHolder(ManagedObject):
    """This is MoKvCfgHolder class."""

    consts = MoKvCfgHolderConsts()
    naming_props = set([])

    mo_meta = MoMeta("MoKvCfgHolder", "moKvCfgHolder", "cfg-kv", VersionMeta.Version321d, "InputOutput", 0x3f, [], ["admin"], ['computeBlade', 'computeRackUnit', 'computeServerUnit', 'lsServer', 'orgOrg'], ['moIpV4AddrKv', 'moIpV6AddrKv', 'moKv', 'moVnicKv'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version321d, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "file_tx_admin_state": MoPropertyMeta("file_tx_admin_state", "fileTxAdminState", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["disabled", "enabled"], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, None, ["config-failure", "not-supported", "ok"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "fileTxAdminState": "file_tx_admin_state", 
        "operState": "oper_state", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.file_tx_admin_state = None
        self.oper_state = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "MoKvCfgHolder", parent_mo_or_dn, **kwargs)



"""This module contains the general information for DcxVIf ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class DcxVIfConsts:
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"
    INST_TYPE_DEFAULT = "default"
    INST_TYPE_DYNAMIC = "dynamic"
    INST_TYPE_DYNAMIC_VF = "dynamic-vf"
    INST_TYPE_MANUAL = "manual"
    LC_ALLOCATED = "allocated"
    LC_AVAILABLE = "available"
    LC_DEALLOCATED = "deallocated"
    LC_REPURPOSED = "repurposed"
    LINK_STATE_ADMIN_DOWN = "admin-down"
    LINK_STATE_DOWN = "down"
    LINK_STATE_ERROR = "error"
    LINK_STATE_OFFLINE = "offline"
    LINK_STATE_UNALLOCATED = "unallocated"
    LINK_STATE_UNAVAILABLE = "unavailable"
    LINK_STATE_UNKNOWN = "unknown"
    LINK_STATE_UP = "up"
    OPER_STATE_ACTIVE = "active"
    OPER_STATE_ADMIN_DOWN = "admin-down"
    OPER_STATE_ERROR = "error"
    OPER_STATE_LINK_DOWN = "link-down"
    OPER_STATE_PASSIVE = "passive"
    OPER_STATE_UNKNOWN = "unknown"
    PROT_ROLE_BACKUP = "backup"
    PROT_ROLE_PRIMARY = "primary"
    PROT_ROLE_UNPROTECTED = "unprotected"
    PROT_STATE_ACTIVE = "active"
    PROT_STATE_NO_PROTECTION = "no-protection"
    PROT_STATE_PASSIVE = "passive"
    QOS_CONTROL_FULL = "full"
    QOS_CONTROL_FULL_WITH_EXCEPTION = "full-with-exception"
    QOS_CONTROL_NONE = "none"
    STATE_CREATE_PEND = "CreatePend"
    STATE_CREATING = "Creating"
    STATE_DESTROY_PEND = "DestroyPend"
    STATE_DESTROYING = "Destroying"
    STATE_MODIFY_PEND = "ModifyPend"
    STATE_MODIFYING = "Modifying"
    STATE_PRESENT = "Present"
    STATE_UNKNOWN = "Unknown"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"


class DcxVIf(ManagedObject):
    """This is DcxVIf class."""

    consts = DcxVIfConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("DcxVIf", "dcxVIf", "vif-[id]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["read-only"], ['adaptorExtEthIf', 'adaptorExtEthIfPc', 'adaptorFcOEIf', 'adaptorHostEthIf', 'adaptorHostFcIf', 'adaptorHostServiceEthIf'], ['faultInst'], ["Get"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cookie": MoPropertyMeta("cookie", "cookie", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []),
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []),
        "inst_type": MoPropertyMeta("inst_type", "instType", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["default", "dynamic", "dynamic-vf", "manual"], []),
        "lc": MoPropertyMeta("lc", "lc", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allocated", "available", "deallocated", "repurposed"], []),
        "link_state": MoPropertyMeta("link_state", "linkState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["admin-down", "down", "error", "offline", "unallocated", "unavailable", "unknown", "up"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active", "admin-down", "error", "link-down", "passive", "unknown"], []),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "prot_peer_id": MoPropertyMeta("prot_peer_id", "protPeerId", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "prot_role": MoPropertyMeta("prot_role", "protRole", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["backup", "primary", "unprotected"], []),
        "prot_state": MoPropertyMeta("prot_state", "protState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active", "no-protection", "passive"], []),
        "qos_control": MoPropertyMeta("qos_control", "qosControl", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["full", "full-with-exception", "none"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["CreatePend", "Creating", "DestroyPend", "Destroying", "ModifyPend", "Modifying", "Present", "Unknown"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
        "tag": MoPropertyMeta("tag", "tag", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "cookie": "cookie", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "id": "id", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "instType": "inst_type", 
        "lc": "lc", 
        "linkState": "link_state", 
        "locale": "locale", 
        "name": "name", 
        "operState": "oper_state", 
        "peerDn": "peer_dn", 
        "protPeerId": "prot_peer_id", 
        "protRole": "prot_role", 
        "protState": "prot_state", 
        "qosControl": "qos_control", 
        "rn": "rn", 
        "sacl": "sacl", 
        "state": "state", 
        "status": "status", 
        "switchId": "switch_id", 
        "tag": "tag", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.admin_state = None
        self.child_action = None
        self.cookie = None
        self.ep_dn = None
        self.if_role = None
        self.if_type = None
        self.inst_type = None
        self.lc = None
        self.link_state = None
        self.locale = None
        self.name = None
        self.oper_state = None
        self.peer_dn = None
        self.prot_peer_id = None
        self.prot_role = None
        self.prot_state = None
        self.qos_control = None
        self.sacl = None
        self.state = None
        self.status = None
        self.switch_id = None
        self.tag = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "DcxVIf", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of EventSendHeartbeat ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("EventSendHeartbeat", "eventSendHeartbeat", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "out_system_time": MethodPropertyMeta("OutSystemTime", "outSystemTime", "DateTime", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "outSystemTime": "out_system_time",
}



"""This module contains the general information for StorageItem ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageItemConsts:
    ALARM_TYPE_MAJOR = "major"
    ALARM_TYPE_MINOR = "minor"
    OPER_STATE_CLEAN = "clean"
    OPER_STATE_CLEAN_WITH_ERRORS = "clean-with-errors"
    OPER_STATE_MOUNTED = "mounted"
    OPER_STATE_NOT_CLEAN = "not-clean"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UNMOUNTED = "unmounted"
    SIZE_NOTHING = "nothing"
    USED_EMPTY = "empty"
    USED_FULL = "full"
    USED_NOT_APPLICABLE = "not-applicable"


class StorageItem(ManagedObject):
    """This is StorageItem class."""

    consts = StorageItemConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("StorageItem", "storageItem", "stor-part-[name]", VersionMeta.Version101e, "InputOutput", 0x3f, [], ["read-only"], ['networkElement'], ['faultInst'], ["Get"])

    prop_meta = {
        "alarm_type": MoPropertyMeta("alarm_type", "alarmType", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["major", "minor"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["clean", "clean-with-errors", "mounted", "not-clean", "unknown", "unmounted"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "size": MoPropertyMeta("size", "size", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["nothing"], ["0-18446744073709551615"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "used": MoPropertyMeta("used", "used", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "full", "not-applicable"], ["0-101"]),
    }

    prop_map = {
        "alarmType": "alarm_type", 
        "childAction": "child_action", 
        "dn": "dn", 
        "name": "name", 
        "operState": "oper_state", 
        "rn": "rn", 
        "sacl": "sacl", 
        "size": "size", 
        "status": "status", 
        "used": "used", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.alarm_type = None
        self.child_action = None
        self.oper_state = None
        self.sacl = None
        self.size = None
        self.status = None
        self.used = None

        ManagedObject.__init__(self, "StorageItem", parent_mo_or_dn, **kwargs)



"""This module contains the general information for MemoryPersistentMemoryLogicalNamespace ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MemoryPersistentMemoryLogicalNamespaceConsts:
    MODE_BLOCK = "block"
    MODE_RAW = "raw"
    SOCKET_ID_SOCKET_1 = "socket-1"
    SOCKET_ID_SOCKET_2 = "socket-2"
    SOCKET_ID_SOCKET_3 = "socket-3"
    SOCKET_ID_SOCKET_4 = "socket-4"
    SOCKET_LOCAL_DIMM_NUMBER_10 = "10"
    SOCKET_LOCAL_DIMM_NUMBER_11 = "11"
    SOCKET_LOCAL_DIMM_NUMBER_12 = "12"
    SOCKET_LOCAL_DIMM_NUMBER_14 = "14"
    SOCKET_LOCAL_DIMM_NUMBER_15 = "15"
    SOCKET_LOCAL_DIMM_NUMBER_16 = "16"
    SOCKET_LOCAL_DIMM_NUMBER_2 = "2"
    SOCKET_LOCAL_DIMM_NUMBER_3 = "3"
    SOCKET_LOCAL_DIMM_NUMBER_4 = "4"
    SOCKET_LOCAL_DIMM_NUMBER_6 = "6"
    SOCKET_LOCAL_DIMM_NUMBER_7 = "7"
    SOCKET_LOCAL_DIMM_NUMBER_8 = "8"
    SOCKET_LOCAL_DIMM_NUMBER_NOT_APPLICABLE = "not-applicable"


class MemoryPersistentMemoryLogicalNamespace(ManagedObject):
    """This is MemoryPersistentMemoryLogicalNamespace class."""

    consts = MemoryPersistentMemoryLogicalNamespaceConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("MemoryPersistentMemoryLogicalNamespace", "memoryPersistentMemoryLogicalNamespace", "lns-[name]", VersionMeta.Version404a, "InputOutput", 0x3ff, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], ['memoryPersistentMemoryPolicy'], [], [None])

    prop_meta = {
        "capacity": MoPropertyMeta("capacity", "capacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, [], ["1-9223372036854775807"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version404a, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["block", "raw"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version404a, MoPropertyMeta.NAMING, 0x20, None, None, r"""[a-zA-Z0-9#_-][a-zA-Z0-9#_ -]{0,62}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "socket_id": MoPropertyMeta("socket_id", "socketId", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["socket-1", "socket-2", "socket-3", "socket-4"], []),
        "socket_local_dimm_number": MoPropertyMeta("socket_local_dimm_number", "socketLocalDimmNumber", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["10", "11", "12", "14", "15", "16", "2", "3", "4", "6", "7", "8", "not-applicable"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "uuid": MoPropertyMeta("uuid", "uuid", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "capacity": "capacity", 
        "childAction": "child_action", 
        "dn": "dn", 
        "mode": "mode", 
        "name": "name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "socketId": "socket_id", 
        "socketLocalDimmNumber": "socket_local_dimm_number", 
        "status": "status", 
        "uuid": "uuid", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.capacity = None
        self.child_action = None
        self.mode = None
        self.sacl = None
        self.socket_id = None
        self.socket_local_dimm_number = None
        self.status = None
        self.uuid = None

        ManagedObject.__init__(self, "MemoryPersistentMemoryLogicalNamespace", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeMcGetReading ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeMcGetReading", "apeMcGetReading", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_mc_ip": MethodPropertyMeta("InMcIp", "inMcIp", "AddressIPv4", "Version142b", "Input", False),
    "in_reading_ids": MethodPropertyMeta("InReadingIds", "inReadingIds", "IdSet", "Version142b", "Input", True),
    "out_reading_vals": MethodPropertyMeta("OutReadingVals", "outReadingVals", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inMcIp": "in_mc_ip",
    "inReadingIds": "in_reading_ids",
    "outReadingVals": "out_reading_vals",
}



"""This module contains the general information for ControllerMgmtDbCheckPol ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ControllerMgmtDbCheckPolConsts:
    RESET_CORRUPT_COUNT_FALSE = "false"
    RESET_CORRUPT_COUNT_NO = "no"
    RESET_CORRUPT_COUNT_TRUE = "true"
    RESET_CORRUPT_COUNT_YES = "yes"
    TRIGGER_HEALTH_CHECK_FALSE = "false"
    TRIGGER_HEALTH_CHECK_NO = "no"
    TRIGGER_HEALTH_CHECK_TRUE = "true"
    TRIGGER_HEALTH_CHECK_YES = "yes"


class ControllerMgmtDbCheckPol(ManagedObject):
    """This is ControllerMgmtDbCheckPol class."""

    consts = ControllerMgmtDbCheckPolConsts()
    naming_props = set([])

    mo_meta = MoMeta("ControllerMgmtDbCheckPol", "controllerMgmtDbCheckPol", "MgmtDbCheckPol", VersionMeta.Version321d, "InputOutput", 0x1ff, [], ["admin"], ['topSystem'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version321d, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "health_check_interval": MoPropertyMeta("health_check_interval", "healthCheckInterval", "uint", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], ["0-168"]),
        "internal_backup_interval": MoPropertyMeta("internal_backup_interval", "internalBackupInterval", "uint", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], ["0-60"]),
        "last_integrity_check_time": MoPropertyMeta("last_integrity_check_time", "lastIntegrityCheckTime", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "last_internal_backup_time": MoPropertyMeta("last_internal_backup_time", "lastInternalBackupTime", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "reset_corrupt_count": MoPropertyMeta("reset_corrupt_count", "resetCorruptCount", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "trigger_health_check": MoPropertyMeta("trigger_health_check", "triggerHealthCheck", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "healthCheckInterval": "health_check_interval", 
        "internalBackupInterval": "internal_backup_interval", 
        "lastIntegrityCheckTime": "last_integrity_check_time", 
        "lastInternalBackupTime": "last_internal_backup_time", 
        "resetCorruptCount": "reset_corrupt_count", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "triggerHealthCheck": "trigger_health_check", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.health_check_interval = None
        self.internal_backup_interval = None
        self.last_integrity_check_time = None
        self.last_internal_backup_time = None
        self.reset_corrupt_count = None
        self.sacl = None
        self.status = None
        self.trigger_health_check = None

        ManagedObject.__init__(self, "ControllerMgmtDbCheckPol", parent_mo_or_dn, **kwargs)



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import assert_equal
from ucsmsdk.ucshandle import UcsHandle


def test_001_create_uri():
    # Create an object of type LsServer with parent dn specified
    # check if the object has the right values populated
    handle = UcsHandle("192.168.1.1", "admin", "password")

    assert_equal(
        handle._UcsSession__create_uri(
            port=None,
            secure=None),
        'https://192.168.1.1:443')

    assert_equal(
        handle._UcsSession__create_uri(
            port=8080,
            secure=None),
        'https://192.168.1.1:8080')

    assert_equal(
        handle._UcsSession__create_uri(
            port=None,
            secure=True),
        'https://192.168.1.1:443')

    assert_equal(
        handle._UcsSession__create_uri(
            port=None,
            secure=False),
        'http://192.168.1.1:80')

    assert_equal(
        handle._UcsSession__create_uri(
            port=444,
            secure=False),
        'http://192.168.1.1:444')



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ucsmsdk.utils.converttopython import convert_to_ucs_python


def test_001_convert_to_from_xml_sp():
    xml_str = '''
 <configConfMos cookie="[hidden]" response="yes"> <inConfigs> <pair
 key="org-root/ls-test_sp_123"> <lsServer agentPolicyName=""
 assignState="unassigned" assocState="unassociated" biosProfileName=""
 bootPolicyName="" configQualifier="" configState="not-applied" descr=""
 dn="org-root/ls-test_sp_123" dynamicConPolicyName="" extIPPoolName="ext-mgmt"
 extIPState="none" fltAggr="0" fsmDescr="" fsmFlags="" fsmPrev="nop"
 fsmProgr="100" fsmRmtInvErrCode="none" fsmRmtInvErrDescr="" fsmRmtInvRslt=""
 fsmStageDescr="" fsmStamp="never" fsmStatus="nop" fsmTry="0"
 hostFwPolicyName="" identPoolName="default" intId="80996" kvmMgmtPolicyName=""
 localDiskPolicyName="" maintPolicyName="" mgmtAccessPolicyName=""
 mgmtFwPolicyName="" name="test_sp_123" operBiosProfileName=""
 operBootPolicyName="" operDynamicConPolicyName="" operExtIPPoolName=""
 operHostFwPolicyName="" operIdentPoolName="" operKvmMgmtPolicyName=""
 operLocalDiskPolicyName="" operMaintPolicyName="" operMgmtAccessPolicyName=""
 operMgmtFwPolicyName="" operPowerPolicyName="" operScrubPolicyName=""
 operSolPolicyName="" operSrcTemplName="" operState="unassociated"
 operStatsPolicyName="" operVconProfileName="" operVmediaPolicyName=""
 owner="management" pnDn="" policyLevel="0" policyOwner="local"
 powerPolicyName="default" propAcl="0" resolveRemote="yes" scrubPolicyName=""
 solPolicyName="" srcTemplName="" statsPolicyName="default" status="created"
 svnicConfig="yes" type="instance" usrLbl="" uuid="derived"
 uuidSuffix="0000-000000000000" vconProfileName="" vmediaPolicyName=""/></pair>
 </inConfigs> </configConfMos>
'''
    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_002_convert_to_from_xml_sp():
    xml_str = '''
<configConfMos
inHierarchical="false">
<inConfigs>
<pair key="org-root/ls-test1234">
<lsServer
agentPolicyName=""
biosProfileName=""
bootPolicyName="default"

descr=""
dn="org-root/ls-test1234"
dynamicConPolicyName=""
extIPPoolName="ext-mgmt"
extIPState="none"
hostFwPolicyName=""
identPoolName="default"
kvmMgmtPolicyName=""
localDiskPolicyName=""
maintPolicyName=""
mgmtAccessPolicyName=""
mgmtFwPolicyName=""
name="test1234"
policyOwner="local"
powerPolicyName="default"
resolveRemote="yes"

sacl="addchild,del,mod"
scrubPolicyName=""
solPolicyName=""
srcTemplName=""
statsPolicyName="default"
status="created"
usrLbl=""
uuid="0"
vconProfileName=""
vmediaPolicyName="">
<lsVConAssign
adminHostPort="ANY"
adminVcon="any"


order="1"
rn="assign-ethernet-vnic-eth0"
sacl="addchild,del,mod"
status="created,modified"
transport="ethernet"
vnicName="eth0">
</lsVConAssign>
<lsVConAssign
adminHostPort="ANY"
adminVcon="any"


order="2"
rn="assign-fc-vnic-fc0"
sacl="addchild,del,mod"
status="created,modified"
transport="fc"
vnicName="fc0">
</lsVConAssign>
<vnicEther
adaptorProfileName=""
addr="derived"
adminCdnName=""
adminHostPort="ANY"
adminVcon="any"
cdnPropInSync="yes"
cdnSource="vnic-name"


identPoolName="default"
mtu="1500"
name="eth0"
nwCtrlPolicyName=""
nwTemplName=""
order="1"
pinToGroupName=""
qosPolicyName=""
rn="ether-eth0"
sacl="addchild,del,mod"
statsPolicyName="default"

switchId="A">
<vnicEtherIf

defaultNet="yes"

name="default"
rn="if-default"
sacl="addchild,del,mod"
>
</vnicEtherIf>
</vnicEther>
<vnicFc
adaptorProfileName=""
addr="derived"
adminCdnName=""
adminHostPort="ANY"
adminVcon="any"
cdnPropInSync="yes"
cdnSource="vnic-name"


identPoolName=""
maxDataFieldSize="2048"
name="fc0"
nwTemplName=""
order="2"
persBind="disabled"
persBindClear="no"
pinToGroupName=""
qosPolicyName=""
rn="fc-fc0"
sacl="addchild,del,mod"
statsPolicyName="default"

switchId="A">
<vnicFcIf


name="default"
rn="if-default"
sacl="addchild,del,mod"
>
</vnicFcIf>
</vnicFc>
<vnicFcNode
addr="pool-derived"


identPoolName="node-default"
rn="fc-node"
sacl="addchild,del,mod"
>
</vnicFcNode>
<lsPower


rn="power"
sacl="addchild,del,mod"
state="admin-up"
>
</lsPower>
<fabricVCon


fabric="NONE"
id="1"
instType="auto"
placement="physical"
rn="vcon-1"
sacl="addchild,del,mod"
select="all"
share="shared"

transport="ethernet,fc">
</fabricVCon>
<fabricVCon


fabric="NONE"
id="2"
instType="auto"
placement="physical"
rn="vcon-2"
sacl="addchild,del,mod"
select="all"
share="shared"

transport="ethernet,fc">
</fabricVCon>
<fabricVCon


fabric="NONE"
id="3"
instType="auto"
placement="physical"
rn="vcon-3"
sacl="addchild,del,mod"
select="all"
share="shared"
transport="ethernet,fc">
</fabricVCon>
<fabricVCon


fabric="NONE"
id="4"
instType="auto"
placement="physical"
rn="vcon-4"
sacl="addchild,del,mod"
select="all"
share="shared"

transport="ethernet,fc">
</fabricVCon>
</lsServer>
</pair>
</inConfigs>
</configConfMos>

'''
    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_003_convert_from_xml_sp_associate():
    xml_str = '''
<configConfMos
inHierarchical="false">
<inConfigs>
<pair key="org-root/org-Cisco/ls-test_sdk_12345">
<lsServer
agentPolicyName=""
biosProfileName=""
bootPolicyName="WIP_BOOT"

descr=""
dn="org-root/org-Cisco/ls-test_sdk_12345"
dynamicConPolicyName=""
extIPPoolName="ext-mgmt"
extIPState="none"
hostFwPolicyName=""
identPoolName=""
kvmMgmtPolicyName=""
localDiskPolicyName=""
maintPolicyName=""
mgmtAccessPolicyName=""
mgmtFwPolicyName=""
policyOwner="local"
powerPolicyName="default"
resolveRemote="yes"

sacl="addchild,del,mod"
scrubPolicyName=""
solPolicyName=""
srcTemplName=""
statsPolicyName="default"
status="modified"
usrLbl=""
uuid="00000000-0000-0000-0000-000000000099"
vconProfileName=""
vmediaPolicyName="">
<lsBinding


pnDn="sys/chassis-1/blade-7"
restrictMigration="no"
rn="pn"
sacl="addchild,del,mod"
>
</lsBinding>
</lsServer>
</pair>
</inConfigs>
</configConfMos>
'''
    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_004_convert_from_xml_sp_disassociate():
    xml_str = '''
    <configConfMos
        inHierarchical="false">
    <inConfigs>
    <pair key="org-root/org-Cisco/ls-test_sdk_12345/pn">
    <lsBinding

    dn="org-root/org-Cisco/ls-test_sdk_12345/pn"

    sacl="addchild,del,mod"
    status="deleted">
    </lsBinding>
    </pair>
    </inConfigs>
    </configConfMos>
    '''
    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_005_convert_from_xml():
    xml_str = '''
    <configConfMos inHierarchical="false">
    <inConfigs>
     <pair key="fabric/lan/A/phys-slot-1-port-10">
      <fabricEthLanEp adminSpeed="10gbps" adminState="enabled"
      autoNegotiate="no" dn="fabric/lan/A/phys-slot-1-port-10"
      ethLinkProfileName="default" flowCtrlPolicy="default"
      name="" portId="10" sacl="addchild,del,mod" slotId="1"
      status="created" usrLbl="">
        </fabricEthLanEp>
     </pair>
    </inConfigs>
    </configConfMos>
    '''

    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_006_convert_from_xml():
    xml_str = '''
    <configConfMos inHierarchical="false">
    <inConfigs>
     <pair key="sys/mgmt/fw-boot-def/bootunit-system">
      <firmwareBootUnit adminState="triggered"
      dn="sys/mgmt/fw-boot-def/bootunit-system" ignoreCompCheck="no"
      mode="install" resetOnActivate="yes" sacl="addchild,del,mod"
      skipValidation="yes" version="3.1(200.13)">
        </firmwareBootUnit>
     </pair>
    </inConfigs>
    </configConfMos>
    '''

    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_007_convert_from_xml():
    xml_str = '''
    <configConfRename
    dn="org-root/ls-test_clone"
    inNewName="test_clone1111"
    inHierarchical="false">
    </configConfRename>
    '''
    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True)


def test_008_convert_from_xml_dumptofile():
    import os

    xml_str = '''
    <configConfRename
    dn="org-root/ls-test_clone"
    inNewName="test_clone1111"
    inHierarchical="false">
    </configConfRename>
    '''

    logfile = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                           "logfile.txt")
    convert_to_ucs_python(xml=True, request=xml_str, dump_xml=True,
                          dump_to_file=True, dump_file_path=logfile)

    assert os.stat(logfile).st_size != 0

    os.remove(logfile)



"""This module contains the general information for SysdebugBackupBehavior ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SysdebugBackupBehaviorConsts:
    CLEAR_ON_BACKUP_FALSE = "false"
    CLEAR_ON_BACKUP_NO = "no"
    CLEAR_ON_BACKUP_TRUE = "true"
    CLEAR_ON_BACKUP_YES = "yes"
    FORMAT_ASCII = "ascii"
    FORMAT_BINARY = "binary"
    INTERVAL_1HOUR = "1hour"
    INTERVAL_1MONTH = "1month"
    INTERVAL_1WEEK = "1week"
    INTERVAL_24HOURS = "24hours"
    INTERVAL_2HOURS = "2hours"
    INTERVAL_4HOURS = "4hours"
    INTERVAL_8HOURS = "8hours"
    INTERVAL_NEVER = "never"
    PROTO_FTP = "ftp"
    PROTO_HTTP = "http"
    PROTO_NFS_COPY = "nfs-copy"
    PROTO_NONE = "none"
    PROTO_SCP = "scp"
    PROTO_SFTP = "sftp"
    PROTO_TFTP = "tftp"


class SysdebugBackupBehavior(ManagedObject):
    """This is SysdebugBackupBehavior class."""

    consts = SysdebugBackupBehaviorConsts()
    naming_props = set([])

    mo_meta = MoMeta("SysdebugBackupBehavior", "sysdebugBackupBehavior", "backup", VersionMeta.Version111j, "InputOutput", 0x3fff, [], ["admin", "operations"], ['sysdebugMEpLogPolicy'], [], ["Get", "Set"])

    prop_meta = {
        "action": MoPropertyMeta("action", "action", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""((defaultValue|none|log-full|on-clear|timer|on-assoc-change),){0,5}(defaultValue|none|log-full|on-clear|timer|on-assoc-change){0,1}""", [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "clear_on_backup": MoPropertyMeta("clear_on_backup", "clearOnBackup", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["false", "no", "true", "yes"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "format": MoPropertyMeta("format", "format", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["ascii", "binary"], []),
        "hostname": MoPropertyMeta("hostname", "hostname", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], []),
        "interval": MoPropertyMeta("interval", "interval", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["1hour", "1month", "1week", "24hours", "2hours", "4hours", "8hours", "never"], []),
        "proto": MoPropertyMeta("proto", "proto", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["ftp", "http", "nfs-copy", "none", "scp", "sftp", "tftp"], []),
        "pwd": MoPropertyMeta("pwd", "pwd", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x200, 0, 64, None, [], []),
        "remote_path": MoPropertyMeta("remote_path", "remotePath", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x400, 1, 128, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x800, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "user": MoPropertyMeta("user", "user", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x2000, 0, 510, None, [], []),
    }

    prop_map = {
        "action": "action", 
        "childAction": "child_action", 
        "clearOnBackup": "clear_on_backup", 
        "dn": "dn", 
        "format": "format", 
        "hostname": "hostname", 
        "interval": "interval", 
        "proto": "proto", 
        "pwd": "pwd", 
        "remotePath": "remote_path", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "user": "user", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.action = None
        self.child_action = None
        self.clear_on_backup = None
        self.format = None
        self.hostname = None
        self.interval = None
        self.proto = None
        self.pwd = None
        self.remote_path = None
        self.sacl = None
        self.status = None
        self.user = None

        ManagedObject.__init__(self, "SysdebugBackupBehavior", parent_mo_or_dn, **kwargs)



"""This module contains the general information for EtherSwitchIntFIo ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EtherSwitchIntFIoConsts:
    ACK_ACK_IN_PROGRESS = "ack-in-progress"
    ACK_ACKNOWLEDGED = "acknowledged"
    ACK_AUTO_ACK = "auto-ack"
    ACK_EVALUATION = "evaluation"
    ACK_OK = "ok"
    ACK_REMOVING = "removing"
    ACK_UN_ACKNOWLEDGED = "un-acknowledged"
    ACK_UN_INITIALIZED = "un-initialized"
    ACK_UNSUPPORTED_CONNECTIVITY = "unsupported-connectivity"
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_ENABLED = "enabled"
    CHASSIS_ID_N_A = "N/A"
    DEL_FE_TS_NEVER = "never"
    DISCOVERY_ABSENT = "absent"
    DISCOVERY_MIS_CONNECT = "mis-connect"
    DISCOVERY_MISSING = "missing"
    DISCOVERY_NEW = "new"
    DISCOVERY_PRESENT = "present"
    DISCOVERY_UN_INITIALIZED = "un-initialized"
    DISCOVERY_UN_SUPPORTED = "un-supported"
    ENCAP_DOT1Q = "dot1q"
    ENCAP_ISL = "isl"
    ENCAP_NEGOTIATE = "negotiate"
    ENCAP_PROPRIETARY = "proprietary"
    ENCAP_UNKNOWN = "unknown"
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"
    MODE_E = "E"
    MODE_F = "F"
    MODE_SD = "SD"
    MODE_ACCESS = "access"
    MODE_FABRIC = "fabric"
    MODE_N_PROXY = "n_proxy"
    MODE_PROMISCUOUS_ACCESS = "promiscuousAccess"
    MODE_PROMISCUOUS_TRUNK = "promiscuousTrunk"
    MODE_TRUNK = "trunk"
    MODE_UNKNOWN = "unknown"
    MODE_VNTAG = "vntag"
    NEW_FE_TS_NEVER = "never"
    OPER_STATE_ADMIN_DOWN = "admin-down"
    OPER_STATE_DOWN = "down"
    OPER_STATE_ERROR_DISABLED = "error-disabled"
    OPER_STATE_FAILED = "failed"
    OPER_STATE_HARDWARE_FAILURE = "hardware-failure"
    OPER_STATE_INDETERMINATE = "indeterminate"
    OPER_STATE_LINK_DOWN = "link-down"
    OPER_STATE_LINK_UP = "link-up"
    OPER_STATE_NO_LICENSE = "no-license"
    OPER_STATE_SFP_NOT_PRESENT = "sfp-not-present"
    OPER_STATE_SOFTWARE_FAILURE = "software-failure"
    OPER_STATE_UDLD_AGGR_DOWN = "udld-aggr-down"
    OPER_STATE_UP = "up"
    PEER_CHASSIS_ID_N_A = "N/A"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    UPLINK_ID_LEFT = "left"
    UPLINK_ID_RIGHT = "right"
    XCVR_TYPE_1000BASECX = "1000basecx"
    XCVR_TYPE_1000BASELH = "1000baselh"
    XCVR_TYPE_1000BASELX = "1000baselx"
    XCVR_TYPE_1000BASESX = "1000basesx"
    XCVR_TYPE_1000BASET = "1000baset"
    XCVR_TYPE_1000BASEUNKNOWN = "1000baseunknown"
    XCVR_TYPE_1000BASEVX = "1000basevx"
    XCVR_TYPE_1000BASEX = "1000basex"
    XCVR_TYPE_1000BASEZX = "1000basezx"
    XCVR_TYPE_10GBASEER = "10gbaseer"
    XCVR_TYPE_10GBASELR = "10gbaselr"
    XCVR_TYPE_10GBASELRM = "10gbaselrm"
    XCVR_TYPE_10GBASELRS = "10gbaselrs"
    XCVR_TYPE_10GBASESR = "10gbasesr"
    XCVR_TYPE_10GBASESRS = "10gbasesrs"
    XCVR_TYPE_10GBASEZR = "10gbasezr"
    XCVR_TYPE_10GBASEZRS = "10gbasezrs"
    XCVR_TYPE_10GBX40DI = "10gbx40di"
    XCVR_TYPE_10GBX40UI = "10gbx40ui"
    XCVR_TYPE_10GBXDI = "10gbxdi"
    XCVR_TYPE_10GBXUI = "10gbxui"
    XCVR_TYPE_CWDM1471 = "cwdm1471"
    XCVR_TYPE_CWDM1531 = "cwdm1531"
    XCVR_TYPE_CWDM1551 = "cwdm1551"
    XCVR_TYPE_DWDMSFP = "dwdmsfp"
    XCVR_TYPE_FET = "fet"
    XCVR_TYPE_H10GACU10M = "h10gacu10m"
    XCVR_TYPE_H10GACU15M = "h10gacu15m"
    XCVR_TYPE_H10GACU1M = "h10gacu1m"
    XCVR_TYPE_H10GACU3M = "h10gacu3m"
    XCVR_TYPE_H10GACU5M = "h10gacu5m"
    XCVR_TYPE_H10GACU7M = "h10gacu7m"
    XCVR_TYPE_H10GACUAOC10M = "h10gacuaoc10m"
    XCVR_TYPE_H10GACUAOC15M = "h10gacuaoc15m"
    XCVR_TYPE_H10GACUAOC1M = "h10gacuaoc1m"
    XCVR_TYPE_H10GACUAOC2M = "h10gacuaoc2m"
    XCVR_TYPE_H10GACUAOC3M = "h10gacuaoc3m"
    XCVR_TYPE_H10GACUAOC5M = "h10gacuaoc5m"
    XCVR_TYPE_H10GACUAOC7M = "h10gacuaoc7m"
    XCVR_TYPE_H10GAOC10M = "h10gaoc10m"
    XCVR_TYPE_H10GAOC15M = "h10gaoc15m"
    XCVR_TYPE_H10GAOC1M = "h10gaoc1m"
    XCVR_TYPE_H10GAOC2M = "h10gaoc2m"
    XCVR_TYPE_H10GAOC3M = "h10gaoc3m"
    XCVR_TYPE_H10GAOC5M = "h10gaoc5m"
    XCVR_TYPE_H10GAOC7M = "h10gaoc7m"
    XCVR_TYPE_H10GCU1_5M = "h10gcu1-5m"
    XCVR_TYPE_H10GCU10M = "h10gcu10m"
    XCVR_TYPE_H10GCU1M = "h10gcu1m"
    XCVR_TYPE_H10GCU2_5M = "h10gcu2-5m"
    XCVR_TYPE_H10GCU2M = "h10gcu2m"
    XCVR_TYPE_H10GCU3M = "h10gcu3m"
    XCVR_TYPE_H10GCU5M = "h10gcu5m"
    XCVR_TYPE_H10GCU7M = "h10gcu7m"
    XCVR_TYPE_H10GLRMSM = "h10glrmsm"
    XCVR_TYPE_H10GTX = "h10gtx"
    XCVR_TYPE_H10GUSR = "h10gusr"
    XCVR_TYPE_H25GAOC10M = "h25gaoc10m"
    XCVR_TYPE_H25GAOC1M = "h25gaoc1m"
    XCVR_TYPE_H25GAOC2M = "h25gaoc2m"
    XCVR_TYPE_H25GAOC3M = "h25gaoc3m"
    XCVR_TYPE_H25GAOC4M = "h25gaoc4m"
    XCVR_TYPE_H25GAOC5M = "h25gaoc5m"
    XCVR_TYPE_H25GAOC7M = "h25gaoc7m"
    XCVR_TYPE_H25GCU1M = "h25gcu1m"
    XCVR_TYPE_H25GCU2M = "h25gcu2m"
    XCVR_TYPE_H25GCU3M = "h25gcu3m"
    XCVR_TYPE_H25GCU4M = "h25gcu4m"
    XCVR_TYPE_H25GCU5M = "h25gcu5m"
    XCVR_TYPE_H25GLRS = "h25glrs"
    XCVR_TYPE_H25GSRS = "h25gsrs"
    XCVR_TYPE_QSFP100G40GBIDI = "qsfp100g40gbidi"
    XCVR_TYPE_QSFP100GAOC10M = "qsfp100gaoc10m"
    XCVR_TYPE_QSFP100GAOC15M = "qsfp100gaoc15m"
    XCVR_TYPE_QSFP100GAOC1M = "qsfp100gaoc1m"
    XCVR_TYPE_QSFP100GAOC20M = "qsfp100gaoc20m"
    XCVR_TYPE_QSFP100GAOC25M = "qsfp100gaoc25m"
    XCVR_TYPE_QSFP100GAOC2M = "qsfp100gaoc2m"
    XCVR_TYPE_QSFP100GAOC30M = "qsfp100gaoc30m"
    XCVR_TYPE_QSFP100GAOC3M = "qsfp100gaoc3m"
    XCVR_TYPE_QSFP100GAOC5M = "qsfp100gaoc5m"
    XCVR_TYPE_QSFP100GAOC7M = "qsfp100gaoc7m"
    XCVR_TYPE_QSFP100GCR4 = "qsfp100gcr4"
    XCVR_TYPE_QSFP100GCU1M = "qsfp100gcu1m"
    XCVR_TYPE_QSFP100GCU2M = "qsfp100gcu2m"
    XCVR_TYPE_QSFP100GCU3M = "qsfp100gcu3m"
    XCVR_TYPE_QSFP100GLR4S = "qsfp100glr4s"
    XCVR_TYPE_QSFP100GSMSR = "qsfp100gsmsr"
    XCVR_TYPE_QSFP100GSR4 = "qsfp100gsr4"
    XCVR_TYPE_QSFP100GSR4S = "qsfp100gsr4s"
    XCVR_TYPE_QSFP40GCR4 = "qsfp40gcr4"
    XCVR_TYPE_QSFP40GCSR4 = "qsfp40gcsr4"
    XCVR_TYPE_QSFP40GER4 = "qsfp40ger4"
    XCVR_TYPE_QSFP40GFET = "qsfp40gfet"
    XCVR_TYPE_QSFP40GLR4 = "qsfp40glr4"
    XCVR_TYPE_QSFP40GSR4 = "qsfp40gsr4"
    XCVR_TYPE_QSFP40GSRBD = "qsfp40gsrbd"
    XCVR_TYPE_QSFP4SFP10GCU1M = "qsfp4sfp10gcu1m"
    XCVR_TYPE_QSFP4SFP10GCU2M = "qsfp4sfp10gcu2m"
    XCVR_TYPE_QSFP4SFP10GCU3M = "qsfp4sfp10gcu3m"
    XCVR_TYPE_QSFP4SFP10GCU5M = "qsfp4sfp10gcu5m"
    XCVR_TYPE_QSFP4SFP25GCU1M = "qsfp4sfp25gcu1m"
    XCVR_TYPE_QSFP4SFP25GCU2M = "qsfp4sfp25gcu2m"
    XCVR_TYPE_QSFP4SFP25GCU3M = "qsfp4sfp25gcu3m"
    XCVR_TYPE_QSFP4SFP25GCU5M = "qsfp4sfp25gcu5m"
    XCVR_TYPE_QSFP4SFP25GUNKNOWN = "qsfp4sfp25gunknown"
    XCVR_TYPE_QSFP4X10GA0C10M = "qsfp4x10ga0c10m"
    XCVR_TYPE_QSFP4X10GA0C1M = "qsfp4x10ga0c1m"
    XCVR_TYPE_QSFP4X10GA0C2M = "qsfp4x10ga0c2m"
    XCVR_TYPE_QSFP4X10GA0C3M = "qsfp4x10ga0c3m"
    XCVR_TYPE_QSFP4X10GA0C5M = "qsfp4x10ga0c5m"
    XCVR_TYPE_QSFP4X10GA0C7M = "qsfp4x10ga0c7m"
    XCVR_TYPE_QSFP4X10GA0CUNKNOWN = "qsfp4x10ga0cunknown"
    XCVR_TYPE_QSFP4X10GAC10M = "qsfp4x10gac10m"
    XCVR_TYPE_QSFP4X10GAC1M = "qsfp4x10gac1m"
    XCVR_TYPE_QSFP4X10GAC3M = "qsfp4x10gac3m"
    XCVR_TYPE_QSFP4X10GAC5M = "qsfp4x10gac5m"
    XCVR_TYPE_QSFP4X10GAC7M = "qsfp4x10gac7m"
    XCVR_TYPE_QSFP4X10GLR = "qsfp4x10glr"
    XCVR_TYPE_QSFP4X10GLRS = "qsfp4x10glrs"
    XCVR_TYPE_QSFPH40GACU10M = "qsfph40gacu10m"
    XCVR_TYPE_QSFPH40GACU1M = "qsfph40gacu1m"
    XCVR_TYPE_QSFPH40GACU3M = "qsfph40gacu3m"
    XCVR_TYPE_QSFPH40GACU5M = "qsfph40gacu5m"
    XCVR_TYPE_QSFPH40GACU7M = "qsfph40gacu7m"
    XCVR_TYPE_QSFPH40GAOC10M = "qsfph40gaoc10m"
    XCVR_TYPE_QSFPH40GAOC15M = "qsfph40gaoc15m"
    XCVR_TYPE_QSFPH40GAOC1M = "qsfph40gaoc1m"
    XCVR_TYPE_QSFPH40GAOC2M = "qsfph40gaoc2m"
    XCVR_TYPE_QSFPH40GAOC3M = "qsfph40gaoc3m"
    XCVR_TYPE_QSFPH40GAOC5M = "qsfph40gaoc5m"
    XCVR_TYPE_QSFPH40GAOC7M = "qsfph40gaoc7m"
    XCVR_TYPE_QSFPH40GAOCUNKNOWN = "qsfph40gaocunknown"
    XCVR_TYPE_QSFPH40GCU1M = "qsfph40gcu1m"
    XCVR_TYPE_QSFPH40GCU2M = "qsfph40gcu2m"
    XCVR_TYPE_QSFPH40GCU3M = "qsfph40gcu3m"
    XCVR_TYPE_QSFPH40GCU5M = "qsfph40gcu5m"
    XCVR_TYPE_QSFPLOOP = "qsfploop"
    XCVR_TYPE_QSFPQSA = "qsfpqsa"
    XCVR_TYPE_QSFPUNKNOWN = "qsfpunknown"
    XCVR_TYPE_SFP = "sfp"
    XCVR_TYPE_UNKNOWN = "unknown"
    XCVR_TYPE_X2 = "x2"


class EtherSwitchIntFIo(ManagedObject):
    """This is EtherSwitchIntFIo class."""

    consts = EtherSwitchIntFIoConsts()
    naming_props = set(['portId'])

    mo_meta = MoMeta("EtherSwitchIntFIo", "etherSwitchIntFIo", "port-[port_id]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["read-only"], ['portGroup'], ['equipmentXcvr', 'etherNiErrStats', 'faultInst', 'portDomainEp'], ["Get"])

    prop_meta = {
        "ack": MoPropertyMeta("ack", "ack", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ack-in-progress", "acknowledged", "auto-ack", "evaluation", "ok", "removing", "un-acknowledged", "un-initialized", "unsupported-connectivity"], []),
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled"], []),
        "aggr_port_id": MoPropertyMeta("aggr_port_id", "aggrPortId", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "del_fe_ts": MoPropertyMeta("del_fe_ts", "delFeTs", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["never"], ["0-18446744073709551615"]),
        "discovery": MoPropertyMeta("discovery", "discovery", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["absent", "mis-connect", "missing", "new", "present", "un-initialized", "un-supported"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "encap": MoPropertyMeta("encap", "encap", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["dot1q", "isl", "negotiate", "proprietary", "unknown"], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []),
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "mac_addr": MoPropertyMeta("mac_addr", "macAddr", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["E", "F", "SD", "access", "fabric", "n_proxy", "promiscuousAccess", "promiscuousTrunk", "trunk", "unknown", "vntag"], []),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "new_fe_ts": MoPropertyMeta("new_fe_ts", "newFeTs", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["never"], ["0-18446744073709551615"]),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["admin-down", "down", "error-disabled", "failed", "hardware-failure", "indeterminate", "link-down", "link-up", "no-license", "sfp-not-present", "software-failure", "udld-aggr-down", "up"], []),
        "peer_aggr_port_id": MoPropertyMeta("peer_aggr_port_id", "peerAggrPortId", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "peer_chassis_id": MoPropertyMeta("peer_chassis_id", "peerChassisId", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "peer_port_id": MoPropertyMeta("peer_port_id", "peerPortId", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "peer_slot_id": MoPropertyMeta("peer_slot_id", "peerSlotId", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "port_id": MoPropertyMeta("port_id", "portId", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x10, None, None, None, [], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "state_qual": MoPropertyMeta("state_qual", "stateQual", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "ts": MoPropertyMeta("ts", "ts", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
        "uplink_id": MoPropertyMeta("uplink_id", "uplinkId", "string", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["left", "right"], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "xcvr_type": MoPropertyMeta("xcvr_type", "xcvrType", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["1000basecx", "1000baselh", "1000baselx", "1000basesx", "1000baset", "1000baseunknown", "1000basevx", "1000basex", "1000basezx", "10gbaseer", "10gbaselr", "10gbaselrm", "10gbaselrs", "10gbasesr", "10gbasesrs", "10gbasezr", "10gbasezrs", "10gbx40di", "10gbx40ui", "10gbxdi", "10gbxui", "cwdm1471", "cwdm1531", "cwdm1551", "dwdmsfp", "fet", "h10gacu10m", "h10gacu15m", "h10gacu1m", "h10gacu3m", "h10gacu5m", "h10gacu7m", "h10gacuaoc10m", "h10gacuaoc15m", "h10gacuaoc1m", "h10gacuaoc2m", "h10gacuaoc3m", "h10gacuaoc5m", "h10gacuaoc7m", "h10gaoc10m", "h10gaoc15m", "h10gaoc1m", "h10gaoc2m", "h10gaoc3m", "h10gaoc5m", "h10gaoc7m", "h10gcu1-5m", "h10gcu10m", "h10gcu1m", "h10gcu2-5m", "h10gcu2m", "h10gcu3m", "h10gcu5m", "h10gcu7m", "h10glrmsm", "h10gtx", "h10gusr", "h25gaoc10m", "h25gaoc1m", "h25gaoc2m", "h25gaoc3m", "h25gaoc4m", "h25gaoc5m", "h25gaoc7m", "h25gcu1m", "h25gcu2m", "h25gcu3m", "h25gcu4m", "h25gcu5m", "h25glrs", "h25gsrs", "qsfp100g40gbidi", "qsfp100gaoc10m", "qsfp100gaoc15m", "qsfp100gaoc1m", "qsfp100gaoc20m", "qsfp100gaoc25m", "qsfp100gaoc2m", "qsfp100gaoc30m", "qsfp100gaoc3m", "qsfp100gaoc5m", "qsfp100gaoc7m", "qsfp100gcr4", "qsfp100gcu1m", "qsfp100gcu2m", "qsfp100gcu3m", "qsfp100glr4s", "qsfp100gsmsr", "qsfp100gsr4", "qsfp100gsr4s", "qsfp40gcr4", "qsfp40gcsr4", "qsfp40ger4", "qsfp40gfet", "qsfp40glr4", "qsfp40gsr4", "qsfp40gsrbd", "qsfp4sfp10gcu1m", "qsfp4sfp10gcu2m", "qsfp4sfp10gcu3m", "qsfp4sfp10gcu5m", "qsfp4sfp25gcu1m", "qsfp4sfp25gcu2m", "qsfp4sfp25gcu3m", "qsfp4sfp25gcu5m", "qsfp4sfp25gunknown", "qsfp4x10ga0c10m", "qsfp4x10ga0c1m", "qsfp4x10ga0c2m", "qsfp4x10ga0c3m", "qsfp4x10ga0c5m", "qsfp4x10ga0c7m", "qsfp4x10ga0cunknown", "qsfp4x10gac10m", "qsfp4x10gac1m", "qsfp4x10gac3m", "qsfp4x10gac5m", "qsfp4x10gac7m", "qsfp4x10glr", "qsfp4x10glrs", "qsfph40gacu10m", "qsfph40gacu1m", "qsfph40gacu3m", "qsfph40gacu5m", "qsfph40gacu7m", "qsfph40gaoc10m", "qsfph40gaoc15m", "qsfph40gaoc1m", "qsfph40gaoc2m", "qsfph40gaoc3m", "qsfph40gaoc5m", "qsfph40gaoc7m", "qsfph40gaocunknown", "qsfph40gcu1m", "qsfph40gcu2m", "qsfph40gcu3m", "qsfph40gcu5m", "qsfploop", "qsfpqsa", "qsfpunknown", "sfp", "unknown", "x2"], []),
    }

    prop_map = {
        "ack": "ack", 
        "adminState": "admin_state", 
        "aggrPortId": "aggr_port_id", 
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "delFeTs": "del_fe_ts", 
        "discovery": "discovery", 
        "dn": "dn", 
        "encap": "encap", 
        "epDn": "ep_dn", 
        "fltAggr": "flt_aggr", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "locale": "locale", 
        "macAddr": "mac_addr", 
        "mode": "mode", 
        "model": "model", 
        "name": "name", 
        "newFeTs": "new_fe_ts", 
        "operState": "oper_state", 
        "peerAggrPortId": "peer_aggr_port_id", 
        "peerChassisId": "peer_chassis_id", 
        "peerDn": "peer_dn", 
        "peerPortId": "peer_port_id", 
        "peerSlotId": "peer_slot_id", 
        "portId": "port_id", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serial": "serial", 
        "slotId": "slot_id", 
        "stateQual": "state_qual", 
        "status": "status", 
        "switchId": "switch_id", 
        "transport": "transport", 
        "ts": "ts", 
        "type": "type", 
        "uplinkId": "uplink_id", 
        "vendor": "vendor", 
        "xcvrType": "xcvr_type", 
    }

    def __init__(self, parent_mo_or_dn, port_id, **kwargs):
        self._dirty_mask = 0
        self.port_id = port_id
        self.ack = None
        self.admin_state = None
        self.aggr_port_id = None
        self.chassis_id = None
        self.child_action = None
        self.del_fe_ts = None
        self.discovery = None
        self.encap = None
        self.ep_dn = None
        self.flt_aggr = None
        self.if_role = None
        self.if_type = None
        self.locale = None
        self.mac_addr = None
        self.mode = None
        self.model = None
        self.name = None
        self.new_fe_ts = None
        self.oper_state = None
        self.peer_aggr_port_id = None
        self.peer_chassis_id = None
        self.peer_dn = None
        self.peer_port_id = None
        self.peer_slot_id = None
        self.revision = None
        self.sacl = None
        self.serial = None
        self.slot_id = None
        self.state_qual = None
        self.status = None
        self.switch_id = None
        self.transport = None
        self.ts = None
        self.type = None
        self.uplink_id = None
        self.vendor = None
        self.xcvr_type = None

        ManagedObject.__init__(self, "EtherSwitchIntFIo", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FabricSanGroupRef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricSanGroupRefConsts:
    OWNER_POLICY_EXTERNAL = "policy-external"
    OWNER_POLICY_GLOBAL = "policy-global"
    OWNER_POLICY_LOCAL = "policy-local"


class FabricSanGroupRef(ManagedObject):
    """This is FabricSanGroupRef class."""

    consts = FabricSanGroupRefConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricSanGroupRef", "fabricSanGroupRef", "san-group-ref-[name]", VersionMeta.Version321d, "InputOutput", 0x3f, [], ["admin", "ls-config", "ls-network", "ls-server"], ['dcxVc', 'vnicFc', 'vnicLanConnTempl', 'vnicSanConnTempl'], ['faultInst'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version321d, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version321d, MoPropertyMeta.NAMING, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "oper_name": MoPropertyMeta("oper_name", "operName", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "owner": MoPropertyMeta("owner", "owner", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, None, ["policy-external", "policy-global", "policy-local"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "name": "name", 
        "operName": "oper_name", 
        "owner": "owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.oper_name = None
        self.owner = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "FabricSanGroupRef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ApeReading ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ApeReadingConsts:
    pass


class ApeReading(ManagedObject):
    """This is ApeReading class."""

    consts = ApeReadingConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("ApeReading", "apeReading", "reading-[id]", VersionMeta.Version101e, "InputOutput", 0xffff, [], ["read-only"], ['apeMcTable'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "is_analog": MoPropertyMeta("is_analog", "is_analog", "ushort", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "sensor_type": MoPropertyMeta("sensor_type", "sensorType", "ushort", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], []),
        "state": MoPropertyMeta("state", "state", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "threshold_lc": MoPropertyMeta("threshold_lc", "thresholdLc", "float", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, [], []),
        "threshold_lnc": MoPropertyMeta("threshold_lnc", "thresholdLnc", "float", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, [], []),
        "threshold_lnr": MoPropertyMeta("threshold_lnr", "thresholdLnr", "float", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, [], []),
        "threshold_uc": MoPropertyMeta("threshold_uc", "thresholdUc", "float", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, [], []),
        "threshold_unc": MoPropertyMeta("threshold_unc", "thresholdUnc", "float", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, [], []),
        "threshold_unr": MoPropertyMeta("threshold_unr", "thresholdUnr", "float", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, [], []),
        "value": MoPropertyMeta("value", "value", "ushort", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8000, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "is_analog": "is_analog", 
        "rn": "rn", 
        "sacl": "sacl", 
        "sensorType": "sensor_type", 
        "state": "state", 
        "status": "status", 
        "thresholdLc": "threshold_lc", 
        "thresholdLnc": "threshold_lnc", 
        "thresholdLnr": "threshold_lnr", 
        "thresholdUc": "threshold_uc", 
        "thresholdUnc": "threshold_unc", 
        "thresholdUnr": "threshold_unr", 
        "value": "value", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.is_analog = None
        self.sacl = None
        self.sensor_type = None
        self.state = None
        self.status = None
        self.threshold_lc = None
        self.threshold_lnc = None
        self.threshold_lnr = None
        self.threshold_uc = None
        self.threshold_unc = None
        self.threshold_unr = None
        self.value = None

        ManagedObject.__init__(self, "ApeReading", parent_mo_or_dn, **kwargs)



"""This module contains the general information for SwatResultstats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SwatResultstatsConsts:
    pass


class SwatResultstats(ManagedObject):
    """This is SwatResultstats class."""

    consts = SwatResultstatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("SwatResultstats", "swatResultstats", "", VersionMeta.Version101e, "InputOutput", 0x3ff, [], ["admin"], [], [], ["Get"])

    prop_meta = {
        "activity_name": MoPropertyMeta("activity_name", "activityName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "false_hits": MoPropertyMeta("false_hits", "falseHits", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []),
        "label": MoPropertyMeta("label", "label", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "total_passes": MoPropertyMeta("total_passes", "totalPasses", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, [], []),
        "true_hits": MoPropertyMeta("true_hits", "trueHits", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, [], []),
    }

    prop_map = {
        "activityName": "activity_name", 
        "childAction": "child_action", 
        "dn": "dn", 
        "falseHits": "false_hits", 
        "label": "label", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "totalPasses": "total_passes", 
        "trueHits": "true_hits", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.activity_name = None
        self.child_action = None
        self.false_hits = None
        self.label = None
        self.sacl = None
        self.status = None
        self.total_passes = None
        self.true_hits = None

        ManagedObject.__init__(self, "SwatResultstats", parent_mo_or_dn, **kwargs)



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""
This module contains the SDK defined exceptions.
"""

import logging

log = logging.getLogger('ucs')


def UcsWarning(warn_str):
    """
    Method to throw warnings.
    """

    # import warnings
    #
    # warnings.warn(string)
    log.debug(warn_str)


class UcsWrapperException(Exception):
    """
    Parent class for all ucswrapper exceptions.
    """

    pass


class UcsLoginError(UcsWrapperException):
    """
    LoginFailure Error
    """

    # message = 'Authentication failed'

    def __init__(self, message, error_code=None):
        super(UcsLoginError, self).__init__(message)


class UcsConnectionError(UcsWrapperException):
    """
    Cannot connect to UCS Manager.
    """

    def __init__(self, message):
        super(UcsConnectionError, self).__init__(message)


class UcsOperationError(UcsWrapperException):
    """
    Configuration Error.
    """

    def __init__(self, operation, error):
        message = "%s failed, error: %s" % (operation, error)
        super(UcsOperationError, self).__init__(message)


class UcsError(Exception):
    """
    Base class for exceptions in Ucs module.
    """

    pass


class UcsException(UcsError):
    """
    Class to catch exception thrown from UCSM.
    """

    def __init__(self, error_code, error_descr):
        self.__error_code = error_code
        self.__error_descr = error_descr

    @property
    def error_code(self):
        """Getter Method of UcsException Class"""
        return self.__error_code

    @property
    def error_descr(self):
        """Getter Method of UcsException Class"""
        return self.__error_descr

    def __str__(self):
        return "[ErrorCode]: %s[ErrorDescription]: %s" % (
            self.__error_code, self.__error_descr)


class UcsValidationException(UcsError):
    """
    Class to handle required attributes validation.
    """

    def __init__(self, error_msg):
        self.__error_msg = error_msg

    @property
    def error_msg(self):
        """Getter Method of UcsValidationException Class"""
        return self.__error_msg

    def __str__(self):
        return "[ErrorMessage]: %s" % (self.__error_msg)



"""This module contains the general information for EquipmentIOCardFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentIOCardFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_EVACUATE_BEGIN = "EvacuateBegin"
    NAME_EVACUATE_EXECUTE = "EvacuateExecute"
    NAME_EVACUATE_FAIL = "EvacuateFail"
    NAME_EVACUATE_SUCCESS = "EvacuateSuccess"
    NAME_FE_CONN_BEGIN = "FeConnBegin"
    NAME_FE_CONN_CONFIGURE_END_POINT = "FeConnConfigureEndPoint"
    NAME_FE_CONN_CONFIGURE_SW_MGMT_END_POINT = "FeConnConfigureSwMgmtEndPoint"
    NAME_FE_CONN_CONFIGURE_VIF_NS = "FeConnConfigureVifNs"
    NAME_FE_CONN_DISCOVER_CHASSIS = "FeConnDiscoverChassis"
    NAME_FE_CONN_ENABLE_CHASSIS = "FeConnEnableChassis"
    NAME_FE_CONN_FAIL = "FeConnFail"
    NAME_FE_CONN_SUCCESS = "FeConnSuccess"
    NAME_FE_PRESENCE_BEGIN = "FePresenceBegin"
    NAME_FE_PRESENCE_CHECK_LICENSE = "FePresenceCheckLicense"
    NAME_FE_PRESENCE_CONFIG_CHASSIS_ID = "FePresenceConfigChassisId"
    NAME_FE_PRESENCE_FAIL = "FePresenceFail"
    NAME_FE_PRESENCE_IDENTIFY = "FePresenceIdentify"
    NAME_FE_PRESENCE_SUCCESS = "FePresenceSuccess"
    NAME_RESET_CMC_BEGIN = "ResetCmcBegin"
    NAME_RESET_CMC_EXECUTE = "ResetCmcExecute"
    NAME_RESET_CMC_FAIL = "ResetCmcFail"
    NAME_RESET_CMC_SUCCESS = "ResetCmcSuccess"
    NAME_RESET_EVACUATE_BEGIN = "ResetEvacuateBegin"
    NAME_RESET_EVACUATE_EXECUTE = "ResetEvacuateExecute"
    NAME_RESET_EVACUATE_FAIL = "ResetEvacuateFail"
    NAME_RESET_EVACUATE_SUCCESS = "ResetEvacuateSuccess"
    NAME_RESET_IOM_BEGIN = "ResetIomBegin"
    NAME_RESET_IOM_EXECUTE = "ResetIomExecute"
    NAME_RESET_IOM_FAIL = "ResetIomFail"
    NAME_RESET_IOM_SUCCESS = "ResetIomSuccess"
    NAME_RESET_PEER_CMC_BEGIN = "ResetPeerCmcBegin"
    NAME_RESET_PEER_CMC_EXECUTE = "ResetPeerCmcExecute"
    NAME_RESET_PEER_CMC_FAIL = "ResetPeerCmcFail"
    NAME_RESET_PEER_CMC_SUCCESS = "ResetPeerCmcSuccess"
    NAME_MUX_OFFLINE_BEGIN = "muxOfflineBegin"
    NAME_MUX_OFFLINE_CLEANUP_ENTRIES = "muxOfflineCleanupEntries"
    NAME_MUX_OFFLINE_FAIL = "muxOfflineFail"
    NAME_MUX_OFFLINE_SUCCESS = "muxOfflineSuccess"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class EquipmentIOCardFsmStage(ManagedObject):
    """This is EquipmentIOCardFsmStage class."""

    consts = EquipmentIOCardFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("EquipmentIOCardFsmStage", "equipmentIOCardFsmStage", "stage-[name]", VersionMeta.Version211a, "OutputOnly", 0xf, [], [""], ['equipmentIOCardFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, None, None, None, None, ["EvacuateBegin", "EvacuateExecute", "EvacuateFail", "EvacuateSuccess", "FeConnBegin", "FeConnConfigureEndPoint", "FeConnConfigureSwMgmtEndPoint", "FeConnConfigureVifNs", "FeConnDiscoverChassis", "FeConnEnableChassis", "FeConnFail", "FeConnSuccess", "FePresenceBegin", "FePresenceCheckLicense", "FePresenceConfigChassisId", "FePresenceFail", "FePresenceIdentify", "FePresenceSuccess", "ResetCmcBegin", "ResetCmcExecute", "ResetCmcFail", "ResetCmcSuccess", "ResetEvacuateBegin", "ResetEvacuateExecute", "ResetEvacuateFail", "ResetEvacuateSuccess", "ResetIomBegin", "ResetIomExecute", "ResetIomFail", "ResetIomSuccess", "ResetPeerCmcBegin", "ResetPeerCmcExecute", "ResetPeerCmcFail", "ResetPeerCmcSuccess", "muxOfflineBegin", "muxOfflineCleanupEntries", "muxOfflineFail", "muxOfflineSuccess", "nop"], []),
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentIOCardFsmStage", parent_mo_or_dn, **kwargs)



"""This module contains the general information for LstorageDiskGroupQualifier ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class LstorageDiskGroupQualifierConsts:
    DRIVE_TYPE_HDD = "HDD"
    DRIVE_TYPE_SSD = "SSD"
    DRIVE_TYPE_UNSPECIFIED = "unspecified"
    MIN_DRIVE_SIZE_UNSPECIFIED = "unspecified"
    NUM_DED_HOT_SPARES_UNSPECIFIED = "unspecified"
    NUM_DRIVES_UNSPECIFIED = "unspecified"
    NUM_GLOB_HOT_SPARES_UNSPECIFIED = "unspecified"
    USE_JBOD_DISKS_NO = "no"
    USE_JBOD_DISKS_YES = "yes"
    USE_REMAINING_DISKS_FALSE = "false"
    USE_REMAINING_DISKS_NO = "no"
    USE_REMAINING_DISKS_TRUE = "true"
    USE_REMAINING_DISKS_YES = "yes"


class LstorageDiskGroupQualifier(ManagedObject):
    """This is LstorageDiskGroupQualifier class."""

    consts = LstorageDiskGroupQualifierConsts()
    naming_props = set([])

    mo_meta = MoMeta("LstorageDiskGroupQualifier", "lstorageDiskGroupQualifier", "disk-group-qual", VersionMeta.Version224b, "InputOutput", 0xfff, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-storage", "ls-storage-policy"], ['lstorageDiskGroupConfigDef', 'lstorageDiskGroupConfigPolicy'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version224b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "drive_type": MoPropertyMeta("drive_type", "driveType", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["HDD", "SSD", "unspecified"], []),
        "min_drive_size": MoPropertyMeta("min_drive_size", "minDriveSize", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["unspecified"], ["0-10240"]),
        "num_ded_hot_spares": MoPropertyMeta("num_ded_hot_spares", "numDedHotSpares", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["unspecified"], ["0-60"]),
        "num_drives": MoPropertyMeta("num_drives", "numDrives", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["unspecified"], ["0-60"]),
        "num_glob_hot_spares": MoPropertyMeta("num_glob_hot_spares", "numGlobHotSpares", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["unspecified"], ["0-60"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "use_jbod_disks": MoPropertyMeta("use_jbod_disks", "useJbodDisks", "string", VersionMeta.Version321d, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["no", "yes"], []),
        "use_remaining_disks": MoPropertyMeta("use_remaining_disks", "useRemainingDisks", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "driveType": "drive_type", 
        "minDriveSize": "min_drive_size", 
        "numDedHotSpares": "num_ded_hot_spares", 
        "numDrives": "num_drives", 
        "numGlobHotSpares": "num_glob_hot_spares", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "useJbodDisks": "use_jbod_disks", 
        "useRemainingDisks": "use_remaining_disks", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.drive_type = None
        self.min_drive_size = None
        self.num_ded_hot_spares = None
        self.num_drives = None
        self.num_glob_hot_spares = None
        self.sacl = None
        self.status = None
        self.use_jbod_disks = None
        self.use_remaining_disks = None

        ManagedObject.__init__(self, "LstorageDiskGroupQualifier", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of AaaKeepAlive ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("AaaKeepAlive", "aaaKeepAlive", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
}

prop_map = {
    "cookie": "cookie",
}



"""This module contains the general information for PolicyControlledInstance ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class PolicyControlledInstanceConsts:
    RESOLVE_TYPE_NAME = "name"
    RESOLVE_TYPE_RN = "rn"


class PolicyControlledInstance(ManagedObject):
    """This is PolicyControlledInstance class."""

    consts = PolicyControlledInstanceConsts()
    naming_props = set(['type', 'name'])

    mo_meta = MoMeta("PolicyControlledInstance", "policyControlledInstance", "ctrlled-[type]-inst-[name]", VersionMeta.Version211a, "InputOutput", 0x1ff, [], ["admin"], ['policyCommunication', 'policyConfigBackup', 'policyDateTime', 'policyDiscovery', 'policyDns', 'policyEquipment', 'policyFault', 'policyInfraFirmware', 'policyMEp', 'policyMonitoring', 'policyPortConfig', 'policyPowerMgmt', 'policyPsu', 'policySecurity', 'policyStorageAutoConfig'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "def_dn": MoPropertyMeta("def_dn", "defDn", "string", VersionMeta.Version211a, MoPropertyMeta.CREATE_ONLY, 0x4, 0, 256, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "external_resolve_name": MoPropertyMeta("external_resolve_name", "externalResolveName", "string", VersionMeta.Version211a, MoPropertyMeta.CREATE_ONLY, 0x10, 0, 510, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x20, 1, 510, None, [], []),
        "resolve_type": MoPropertyMeta("resolve_type", "resolveType", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["name", "rn"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x100, 1, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "defDn": "def_dn", 
        "dn": "dn", 
        "externalResolveName": "external_resolve_name", 
        "name": "name", 
        "resolveType": "resolve_type", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, name, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.name = name
        self.child_action = None
        self.def_dn = None
        self.external_resolve_name = None
        self.resolve_type = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "PolicyControlledInstance", parent_mo_or_dn, **kwargs)



"""This module contains the general information for VnicLanConnTempl ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class VnicLanConnTemplConsts:
    CDN_SOURCE_USER_DEFINED = "user-defined"
    CDN_SOURCE_VNIC_NAME = "vnic-name"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    REDUNDANCY_PAIR_TYPE_NONE = "none"
    REDUNDANCY_PAIR_TYPE_PRIMARY = "primary"
    REDUNDANCY_PAIR_TYPE_SECONDARY = "secondary"
    SWITCH_ID_A = "A"
    SWITCH_ID_A_B = "A-B"
    SWITCH_ID_B = "B"
    SWITCH_ID_B_A = "B-A"
    SWITCH_ID_NONE = "NONE"
    TEMPL_TYPE_INITIAL_TEMPLATE = "initial-template"
    TEMPL_TYPE_UPDATING_TEMPLATE = "updating-template"


class VnicLanConnTempl(ManagedObject):
    """This is VnicLanConnTempl class."""

    consts = VnicLanConnTemplConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("VnicLanConnTempl", "vnicLanConnTempl", "lan-conn-templ-[name]", VersionMeta.Version101e, "InputOutput", 0x1fffff, [], ["admin", "ls-network", "ls-network-policy"], ['orgOrg'], ['fabricNetGroupRef', 'fabricSanGroupRef', 'faultInst', 'vnicDynamicConPolicyRef', 'vnicEtherIf', 'vnicFcOEIf', 'vnicUsnicConPolicyRef', 'vnicVmqConPolicyRef'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "admin_cdn_name": MoPropertyMeta("admin_cdn_name", "adminCdnName", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "cdn_source": MoPropertyMeta("cdn_source", "cdnSource", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["user-defined", "vnic-name"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x8, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "ident_pool_name": MoPropertyMeta("ident_pool_name", "identPoolName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "mtu": MoPropertyMeta("mtu", "mtu", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], ["1500-9000"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "nw_ctrl_policy_name": MoPropertyMeta("nw_ctrl_policy_name", "nwCtrlPolicyName", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_ident_pool_name": MoPropertyMeta("oper_ident_pool_name", "operIdentPoolName", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "oper_nw_ctrl_policy_name": MoPropertyMeta("oper_nw_ctrl_policy_name", "operNwCtrlPolicyName", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "oper_peer_redundancy_templ_name": MoPropertyMeta("oper_peer_redundancy_templ_name", "operPeerRedundancyTemplName", "string", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "oper_qos_policy_name": MoPropertyMeta("oper_qos_policy_name", "operQosPolicyName", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "oper_stats_policy_name": MoPropertyMeta("oper_stats_policy_name", "operStatsPolicyName", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "peer_redundancy_templ_name": MoPropertyMeta("peer_redundancy_templ_name", "peerRedundancyTemplName", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "pin_to_group_name": MoPropertyMeta("pin_to_group_name", "pinToGroupName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, ["local", "pending-policy", "policy"], []),
        "qos_policy_name": MoPropertyMeta("qos_policy_name", "qosPolicyName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "redundancy_pair_type": MoPropertyMeta("redundancy_pair_type", "redundancyPairType", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, ["none", "primary", "secondary"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8000, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stats_policy_name": MoPropertyMeta("stats_policy_name", "statsPolicyName", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40000, None, None, None, ["A", "A-B", "B", "B-A", "NONE"], []),
        "target": MoPropertyMeta("target", "target", "string", VersionMeta.Version101e, MoPropertyMeta.CREATE_ONLY, 0x80000, None, None, r"""((vm|adaptor|defaultValue),){0,2}(vm|adaptor|defaultValue){0,1}""", [], []),
        "templ_type": MoPropertyMeta("templ_type", "templType", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100000, None, None, None, ["initial-template", "updating-template"], []),
    }

    prop_map = {
        "adminCdnName": "admin_cdn_name", 
        "cdnSource": "cdn_source", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "identPoolName": "ident_pool_name", 
        "intId": "int_id", 
        "mtu": "mtu", 
        "name": "name", 
        "nwCtrlPolicyName": "nw_ctrl_policy_name", 
        "operIdentPoolName": "oper_ident_pool_name", 
        "operNwCtrlPolicyName": "oper_nw_ctrl_policy_name", 
        "operPeerRedundancyTemplName": "oper_peer_redundancy_templ_name", 
        "operQosPolicyName": "oper_qos_policy_name", 
        "operStatsPolicyName": "oper_stats_policy_name", 
        "peerRedundancyTemplName": "peer_redundancy_templ_name", 
        "pinToGroupName": "pin_to_group_name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "qosPolicyName": "qos_policy_name", 
        "redundancyPairType": "redundancy_pair_type", 
        "rn": "rn", 
        "sacl": "sacl", 
        "statsPolicyName": "stats_policy_name", 
        "status": "status", 
        "switchId": "switch_id", 
        "target": "target", 
        "templType": "templ_type", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.admin_cdn_name = None
        self.cdn_source = None
        self.child_action = None
        self.descr = None
        self.ident_pool_name = None
        self.int_id = None
        self.mtu = None
        self.nw_ctrl_policy_name = None
        self.oper_ident_pool_name = None
        self.oper_nw_ctrl_policy_name = None
        self.oper_peer_redundancy_templ_name = None
        self.oper_qos_policy_name = None
        self.oper_stats_policy_name = None
        self.peer_redundancy_templ_name = None
        self.pin_to_group_name = None
        self.policy_level = None
        self.policy_owner = None
        self.qos_policy_name = None
        self.redundancy_pair_type = None
        self.sacl = None
        self.stats_policy_name = None
        self.status = None
        self.switch_id = None
        self.target = None
        self.templ_type = None

        ManagedObject.__init__(self, "VnicLanConnTempl", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FirmwareUcscInfo ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwareUcscInfoConsts:
    CONN_PROTOCOL_IPV4 = "ipv4"
    CONN_PROTOCOL_IPV6 = "ipv6"
    CONN_PROTOCOL_UNKNOWN = "unknown"


class FirmwareUcscInfo(ManagedObject):
    """This is FirmwareUcscInfo class."""

    consts = FirmwareUcscInfoConsts()
    naming_props = set([])

    mo_meta = MoMeta("FirmwareUcscInfo", "firmwareUcscInfo", "ucsc-info", VersionMeta.Version222c, "InputOutput", 0x1f, [], ["admin"], ['firmwareBootDefinition', 'firmwareCatalogue', 'firmwareInstallable'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version222c, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "conn_protocol": MoPropertyMeta("conn_protocol", "connProtocol", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ipv4", "ipv6", "unknown"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "host": MoPropertyMeta("host", "host", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^[A-Za-z]([A-Za-z0-9-]*[A-Za-z0-9])?$|^[A-Za-z0-9]([A-Za-z0-9-]*[A-Za-z0-9])?(\.[A-Za-z0-9]([A-Za-z0-9-]*[A-Za-z0-9])?)*(\.[A-Za-z]([A-Za-z0-9-]*[A-Za-z0-9])?)$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version223a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "connProtocol": "conn_protocol", 
        "dn": "dn", 
        "host": "host", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.conn_protocol = None
        self.host = None
        self.sacl = None
        self.status = None
        self.version = None

        ManagedObject.__init__(self, "FirmwareUcscInfo", parent_mo_or_dn, **kwargs)
